Coverage for src/remedapy/starts_with.py: 100%

1 from collections.abc import Callable

2 from typing import overload

3

4 from remedapy.decorator import make_data_last

5

6

7@overload

8 def starts_with(data: str, prefix: str, /) -> bool: ...

9

10

11@overload

12 def starts_with(prefix: str, /) -> Callable[[str], bool]: ...

13

14

15@make_data_last

16 def starts_with(data: str, prefix: str, /) -> bool:

17 return data.startswith(prefix)